@@ -5,7 +5,9 @@ using PyScaffold
 """
 
 import logging
+import shutil
 import subprocess
+import sys
 from collections.abc import Iterable
 
 import click
@@ -86,11 +88,18 @@ def main():
     ).lower()
 
     if is_data_sci_proj == "y":
-        data_sci_cmds = str(
-            "putup '{}' --description '{}' --url '{}' --license '{}' --dsproject".format(
-                project_name, description, url, license
-            )
-        )
+        if sys.platform == "win32":
+            data_sci_cmds = ["cmd", "/c", shutil.which("putup")]
+        else:
+            data_sci_cmds = ["putup"]
+        data_sci_cmds.append("{}".format(project_name))
+        data_sci_cmds.append("--description")
+        data_sci_cmds.append("{}".format(description))
+        data_sci_cmds.append("--url")
+        data_sci_cmds.append("{}".format(url))
+        data_sci_cmds.append("--license")
+        data_sci_cmds.append("{}".format(license))
+        data_sci_cmds.append("--dsproject")
 
     make_tox = prompt_choice(
         "Generate config files for automated testing using tox? ",
@@ -100,7 +109,7 @@ def main():
 
     if make_tox == "y":
         if is_data_sci_proj == "y":
-            data_sci_cmds += " --tox"
+            data_sci_cmds.append("--tox")
         else:
             extensions.append(Tox("tox"))
 
@@ -110,7 +119,7 @@ def main():
 
     if create_travis == "y":
         if is_data_sci_proj == "y":
-            data_sci_cmds += " --travis"
+            data_sci_cmds.append("--travis")
         else:
             extensions.append(Travis("travis"))
 
@@ -125,7 +134,7 @@ def main():
 
     if is_data_sci_proj == "y":
         # setup datascience project using putup
-        subprocess.check_output(data_sci_cmds, shell=True)  # need to test on windows
+        subprocess.call(data_sci_cmds)
     else:
         create_project(
             project=project_name,
